@@ -1,13 +1,12 @@
 """Client module."""
 
 from metaloop.client.mds import *
-from metaloop.utils import *
+from metaloop.client.x_api import *
 from metaloop.client.cloud_storage import *
 
 __all__ = [
     "MDS",
-    "config",
+    "X_API",
     "CloudClient",
-    "Job",
-    "Item",
+    "CloudConfig",
 ]
