@@ -10,11 +10,13 @@ from typing import Dict, Optional, Union, List
 import boto3
 from boto3 import Session
 from boto3.s3.transfer import TransferConfig
+from botocore import UNSIGNED
 from botocore.client import BaseClient
+from botocore.config import Config
 from tqdm import tqdm
 
 from metaloop.client.x_api import X_API
-from metaloop.exception import ResourceNotExistError
+from metaloop.exception import ResourceNotExistError, AccessDeniedError, ClientError
 
 
 class CloudConfig:
@@ -90,7 +92,7 @@ class CloudClient:
     @staticmethod
     def _get_client(
             identifier: str,
-            validate: Optional[bool] = True
+            validate: Optional[bool] = False
     ) -> BaseClient:
         try:
             config = _CLOUD_CONFIG[identifier]
@@ -103,13 +105,16 @@ class CloudClient:
             session = boto3.Session(config.access_key_id, config.secret_access_key)
             _CLOUD_SESSION[identifier] = session
 
-        client = session.client(service_name="s3", endpoint_url=config.endpoint)
+        if not config.access_key_id:
+            client = session.client(service_name="s3", endpoint_url=config.endpoint, config=Config(signature_version=UNSIGNED))
+        else:
+            client = session.client(service_name="s3", endpoint_url=config.endpoint)
 
-        # if validate:
-        #     try:
-        #         client.list_buckets()
-        #     except ClientError as error:
-        #         raise AccessDeniedError(message="fail to connect to s3 endpoint") from error
+        if validate:
+            try:
+                client.list_buckets()
+            except ClientError as error:
+                raise AccessDeniedError(message="fail to connect to s3 endpoint") from error
 
         return client
 
@@ -280,7 +285,7 @@ class CloudClient:
         if not os.path.exists(os.path.dirname(file_name)):
             os.makedirs(os.path.dirname(file_name), 0o0755)
 
-        client = CloudClient._get_client(identifier, False)
+        client = CloudClient._get_client(identifier)
         client.download_file(bucket, key, file_name)
 
         return image_path if image_path else key
@@ -292,7 +297,7 @@ class CloudClient:
             key: str,
             fileobj
     ):
-        client = CloudClient._get_client(identifier, False)
+        client = CloudClient._get_client(identifier)
         client.download_fileobj(Bucket=bucket, Key=key, Fileobj=fileobj)
 
     @staticmethod
@@ -336,7 +341,7 @@ class CloudClient:
                 if key.endswith("/"):
                     continue
 
-                file_name = os.path.join(file_path, key)
+                file_name = os.path.join(file_path, key[len(prefix.rstrip('/')) + 1:])
                 if not os.path.exists(os.path.dirname(file_name)):
                     os.makedirs(os.path.dirname(file_name), 0o0755)
 
