@@ -273,11 +273,14 @@ class MDS:
             bucket: str,
             file_path: str,
             upload_prefix: Optional[str] = "",
-            storage_type: Optional[str] = "local",
+            storage_type: Optional[str] = None,
             identifier: Optional[str] = None
     ):
         if not identifier:
-            s3_config = CloudClient.get_cloud_storage_config(self._x_api, "", storage_type=storage_type)
+            if storage_type:
+                s3_config = CloudClient.get_cloud_storage_config(self._x_api, "", storage_type)
+            else:
+                s3_config = CloudClient.get_cloud_storage_config(self._x_api, bucket)
             identifier = s3_config.identifier
         if os.path.isdir(file_path):
             CloudClient.upload_files_parallel(identifier, bucket, file_path, upload_prefix, 1, 8)
@@ -290,11 +293,14 @@ class MDS:
             bucket: str,
             prefix: str,
             file_path: str,
-            storage_type: Optional[str] = "local",
+            storage_type: Optional[str] = None,
             identifier: Optional[str] = None
     ):
         if not identifier:
-            s3_config = CloudClient.get_cloud_storage_config(self._x_api, "", storage_type=storage_type)
+            if storage_type:
+                s3_config = CloudClient.get_cloud_storage_config(self._x_api, "", storage_type)
+            else:
+                s3_config = CloudClient.get_cloud_storage_config(self._x_api, bucket)
             identifier = s3_config.identifier
         CloudClient.download_files_parallel(identifier, bucket, prefix, file_path, 1, 8)
 
