@@ -4,6 +4,7 @@ from typing import Dict, Any, Optional, List
 
 from requests_toolbelt import MultipartEncoder
 from s3transfer.constants import MB
+from requests.models import Response
 
 from metaloop.client.requests import Client
 from metaloop.exception import ResourceNotExistError, InvalidParamsError, InternalServerError
@@ -343,6 +344,48 @@ class X_API:
             self,
             url: str
     ) -> List[str]:
+        response = self.get_input_json(url)
+        lines = self.read_lines(response)
+        for retryTimes in range(3):
+            if self.check_completion(response):
+                break
+            print(self.get_retry_str(retryTimes))
+            response = self.get_input_json(url)
+            lines = self.read_lines(response)
+
+        export_list: List[Any] = []
+        for line in lines:
+            export_list.append(json.loads(line))
+
+        return export_list
+    
+    def get_retry_str(self, retry: int) -> str:
+        retry_str = ''
+        if retry + 1 == 1:
+            retry_str = '1st'
+        elif retry + 1 == 2:
+            retry_str = '2nd'
+        elif retry + 1 == 3:
+            retry_str = '3rd'
+        else:
+            retry_str = str(retry) + 'th'
+        return 'retry {} time ...'.format(retry_str)
+
+    def check_completion(self, response: Response) -> bool:
+        content_len = int(response.headers.get("Content-Length"))
+        actual_len = response.raw.tell()
+        if actual_len != content_len:
+            print('Response Content-Length {} vs actual reading length {}'.format(content_len, actual_len))
+            return False
+        return True
+
+    def read_lines(self, response: Response) -> List[str]:
+        lines: List[str] = []
+        for line in response.iter_lines(chunk_size=1 * MB):
+            lines.append(line)
+        return lines
+
+    def get_input_json(self, url: str) -> Response:
         if url.find("abaddonapi") > -1:
             section = url.split("abaddonapi/v1/")[1]
             response = self._client.open_api_do("GET", section, "", stream=True, timeout=3600)
@@ -351,12 +394,7 @@ class X_API:
             response = self._client.open_api_do("GET", section, "", stream=True, timeout=3600)
         else:
             response = self._client.do("GET", url, timeout=3600)
-
-        export_list: List[Any] = []
-        for line in response.iter_lines(chunk_size=1 * MB):
-            export_list.append(json.loads(line))
-
-        return export_list
+        return response
 
     def post_multipart_formdata(
             self,
