@@ -20,7 +20,7 @@ def get_data(mds_client, dataset_ids, flag='train'):
 
     output_path = os.path.join(args.output_path, flag)
     if not os.path.exists(output_path):
-        os.mkdir(output_path)
+        os.makedirs(output_path, 0o0755, True)
 
     mds_client.export_annotated_data(dataset_ids.split(','), output_path)
     if os.path.exists(os.path.join(output_path, 'output.json')):
@@ -31,7 +31,7 @@ def main(args):
     mds_client = MDS(args.user_token, args.api_addr)
 
     get_data(mds_client, args.train_dataset_ids, 'train')
-    get_data(mds_client, args.train_dataset_ids, 'test')
+    get_data(mds_client, args.test_dataset_ids, 'test')
 
 
 if __name__ == '__main__':
