@@ -4,11 +4,16 @@
 #
 
 """Utility classes."""
-from metaloop.utils.requests import Tqdm, UserResponse, UserSession, config, get_session
+from metaloop.utils.requests import *
+from metaloop.utils.file_helper import *
 
 __all__ = [
+    "Tqdm",
     "UserResponse",
     "UserSession",
     "config",
     "get_session",
+    "get_file_type",
+    "get_bucket_and_key",
+    "get_user_origin_path"
 ]
